@@ -96,6 +96,9 @@ module IAIConvert
   function convert_to_jl(o::Array{PyObject})
     convert.(String, o)
   end
+  function convert_to_jl(o::AbstractDict)
+    Dict(convert_to_jl(k) => convert_to_jl(v) for (k, v) in o)
+  end
 
   function convert_to_jl(p::Pair)
     convert_to_jl(p.first) => convert_to_jl(p.second)
