@@ -12,7 +12,7 @@ class RandomForestClassifier(RandomForestLearner, ClassificationLearner):
     """Learner for training random forests for classification problems.
 
     Julia Equivalent:
-    `IAI.RandomForestClassifier <https://docs.interpretable.ai/v2.2.0/Heuristics/reference/#IAI.RandomForestClassifier>`
+    `IAI.RandomForestClassifier <https://docs.interpretable.ai/v3.0.0/Heuristics/reference/#IAI.RandomForestClassifier>`
 
     Examples
     --------
@@ -37,7 +37,7 @@ class RandomForestRegressor(RandomForestLearner, RegressionLearner):
     """Learner for training random forests for regression problems.
 
     Julia Equivalent:
-    `IAI.RandomForestRegressor <https://docs.interpretable.ai/v2.2.0/Heuristics/reference/#IAI.RandomForestRegressor>`
+    `IAI.RandomForestRegressor <https://docs.interpretable.ai/v3.0.0/Heuristics/reference/#IAI.RandomForestRegressor>`
 
     Examples
     --------
@@ -62,7 +62,7 @@ class RandomForestSurvivalLearner(RandomForestLearner, SurvivalLearner):
     """Learner for training random forests for survival problems.
 
     Julia Equivalent:
-    `IAI.RandomForestSurvivalLearner <https://docs.interpretable.ai/v2.2.0/Heuristics/reference/#IAI.RandomForestSurvivalLearner>`
+    `IAI.RandomForestSurvivalLearner <https://docs.interpretable.ai/v3.0.0/Heuristics/reference/#IAI.RandomForestSurvivalLearner>`
 
     Examples
     --------
@@ -90,7 +90,7 @@ class XGBoostLearner(Learner):
         """Write the internal booster saved in the learner to `filename`.
 
         Julia Equivalent:
-        `IAI.write_booster <https://docs.interpretable.ai/v2.2.0/Heuristics/reference/#IAI.write_booster>`
+        `IAI.write_booster <https://docs.interpretable.ai/v3.0.0/Heuristics/reference/#IAI.write_booster>`
 
         Examples
         --------
@@ -107,7 +107,7 @@ class XGBoostLearner(Learner):
         """Calculate SHAP values for all points in the features `X` using `lnr`.
 
         Julia Equivalent:
-        `IAI.predict_shap <https://docs.interpretable.ai/v2.2.0/Heuristics/reference/#IAI.predict_shap>`
+        `IAI.predict_shap <https://docs.interpretable.ai/v3.0.0/Heuristics/reference/#IAI.predict_shap>`
 
         Examples
         --------
@@ -125,7 +125,7 @@ class XGBoostClassifier(XGBoostLearner, ClassificationLearner):
     """Learner for training XGBoost models for classification problems.
 
     Julia Equivalent:
-    `IAI.XGBoostClassifier <https://docs.interpretable.ai/v2.2.0/Heuristics/reference/#IAI.XGBoostClassifier>`
+    `IAI.XGBoostClassifier <https://docs.interpretable.ai/v3.0.0/Heuristics/reference/#IAI.XGBoostClassifier>`
 
     Examples
     --------
@@ -150,7 +150,7 @@ class XGBoostRegressor(XGBoostLearner, RegressionLearner):
     """Learner for training XGBoost models for regression problems.
 
     Julia Equivalent:
-    `IAI.XGBoostRegressor <https://docs.interpretable.ai/v2.2.0/Heuristics/reference/#IAI.XGBoostRegressor>`
+    `IAI.XGBoostRegressor <https://docs.interpretable.ai/v3.0.0/Heuristics/reference/#IAI.XGBoostRegressor>`
 
     Examples
     --------
@@ -175,7 +175,7 @@ class XGBoostSurvivalLearner(XGBoostLearner, SurvivalLearner):
     """Learner for training XGBoost models for survival problems.
 
     Julia Equivalent:
-    `IAI.XGBoostSurvivalLearner <https://docs.interpretable.ai/v2.2.0/Heuristics/reference/#IAI.XGBoostSurvivalLearner>`
+    `IAI.XGBoostSurvivalLearner <https://docs.interpretable.ai/v3.0.0/Heuristics/reference/#IAI.XGBoostSurvivalLearner>`
 
     Examples
     --------
@@ -203,7 +203,7 @@ class GLMNetLearner(Learner):
         """Return the number of fits along the path in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_num_fits <https://docs.interpretable.ai/v2.2.0/Heuristics/reference/#IAI.get_num_fits>`
+        `IAI.get_num_fits <https://docs.interpretable.ai/v3.0.0/Heuristics/reference/#IAI.get_num_fits>`
 
         Examples
         --------
@@ -220,7 +220,7 @@ class GLMNetLearner(Learner):
         """Return the constant term in the prediction in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_prediction_constant <https://docs.interpretable.ai/v2.2.0/Heuristics/reference/#IAI.get_prediction_constant>`
+        `IAI.get_prediction_constant <https://docs.interpretable.ai/v3.0.0/Heuristics/reference/#IAI.get_prediction_constant>`
 
         Examples
         --------
@@ -247,7 +247,7 @@ class GLMNetLearner(Learner):
         prediction in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_prediction_weights <https://docs.interpretable.ai/v2.2.0/Heuristics/reference/#IAI.get_prediction_weights>`
+        `IAI.get_prediction_weights <https://docs.interpretable.ai/v3.0.0/Heuristics/reference/#IAI.get_prediction_weights>`
 
         Examples
         --------
@@ -281,7 +281,7 @@ class GLMNetCVRegressor(GLMNetCVLearner, RegressionLearner):
     cross-validation.
 
     Julia Equivalent:
-    `IAI.GLMNetCVRegressor <https://docs.interpretable.ai/v2.2.0/Heuristics/reference/#IAI.GLMNetCVRegressor>`
+    `IAI.GLMNetCVRegressor <https://docs.interpretable.ai/v3.0.0/Heuristics/reference/#IAI.GLMNetCVRegressor>`
 
     Examples
     --------
@@ -307,7 +307,7 @@ class GLMNetCVClassifier(GLMNetCVLearner, ClassificationLearner):
     cross-validation.
 
     Julia Equivalent:
-    `IAI.GLMNetCVClassifier <https://docs.interpretable.ai/v2.2.0/Heuristics/reference/#IAI.GLMNetCVClassifier>`
+    `IAI.GLMNetCVClassifier <https://docs.interpretable.ai/v3.0.0/Heuristics/reference/#IAI.GLMNetCVClassifier>`
 
     Examples
     --------
@@ -326,3 +326,85 @@ class GLMNetCVClassifier(GLMNetCVLearner, ClassificationLearner):
         _requires_iai_version("2.3.0", "GLMNetCVClassifier")
         jl_obj = _IAI.GLMNetCVClassifier_convert(*args, **kwargs)
         super().__init__(jl_obj)
+
+
+class GLMNetCVSurvivalLearner(GLMNetCVLearner, SurvivalLearner):
+    """Learner for training GLMNet models for survival problems with
+    cross-validation.
+
+    Julia Equivalent:
+    `IAI.GLMNetCVSurvivalLearner <https://docs.interpretable.ai/v3.0.0/Heuristics/reference/#IAI.GLMNetCVSurvivalLearner>`
+
+    Examples
+    --------
+    >>> iai.GLMNetCVSurvivalLearner(**kwargs)
+
+    Parameters
+    ----------
+    Use keyword arguments to set parameters on the resulting learner. Refer to
+    the Julia documentation for available parameters.
+
+    Compatibility
+    -------------
+    Requires IAI version 3.0 or higher.
+    """
+    def __init__(self, *args, **kwargs):
+        _requires_iai_version("3.0.0", "GLMNetCVSurvivalLearner")
+        jl_obj = _IAI.GLMNetCVSurvivalLearner_convert(*args, **kwargs)
+        super().__init__(jl_obj)
+
+    def predict_expected_survival_time(self, *args, **kwargs):
+        """Return the expected survival time estimate made by the learner for
+        each point in the data `X`.
+
+        Julia Equivalent:
+        `IAI.predict_expected_survival_time <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.predict_expected_survival_time>`
+
+        Examples
+        --------
+        Return the expected survival time made by the best fit on the path in
+        the learner.
+
+        >>> lnr.predict_expected_survival_time(X)
+
+        Return the expected survival time made by the fit at `fit_index` on the
+        path in the learner.
+
+        >>> lnr.predict_expected_survival_time(X, fit_index)
+
+        Compatibility
+        -------------
+        Requires IAI version 3.0 or higher.
+        """
+        _requires_iai_version("3.0.0", "predict_expected_survival_time")
+        return _IAI.predict_expected_survival_time_convert(self._jl_obj, *args,
+                                                           **kwargs)
+
+    def predict_hazard(self, *args, **kwargs):
+        """Return the fitted hazard coefficient estimate made by the learner
+        for each point in the data `X`.
+
+        A higher hazard coefficient estimate corresponds to a smaller predicted
+        survival time.
+
+        Julia Equivalent:
+        `IAI.predict_hazard <https://docs.interpretable.ai/v3.0.0/IAIBase/reference/#IAI.predict_hazard>`
+
+        Examples
+        --------
+        Return the hazard coefficient estimated made by the best fit on the
+        path in the learner.
+
+        >>> lnr.predict_hazard(X)
+
+        Return the hazard coefficient estimated made by the fit at `fit_index`
+        on the path in the learner.
+
+        >>> lnr.predict_hazard(X, fit_index)
+
+        Compatibility
+        -------------
+        Requires IAI version 3.0 or higher.
+        """
+        _requires_iai_version("3.0.0", "predict_hazard")
+        return _IAI.predict_hazard_convert(self._jl_obj, *args, **kwargs)
