@@ -131,6 +131,9 @@ def _get_learner_type(jl_obj):
         L = MeanImputationLearner
     elif _Main.isa(jl_obj, _IAI.RandImputationLearner):
         L = RandImputationLearner
+    elif (not _iai_version_less_than("3.0.0") and
+          _Main.isa(jl_obj, _IAI.ZeroImputationLearner)):
+        L = ZeroImputationLearner
     elif (not _iai_version_less_than("2.1.0") and
           _Main.isa(jl_obj, _IAI.RandomForestClassifier)):
         L = RandomForestClassifier
@@ -149,6 +152,30 @@ def _get_learner_type(jl_obj):
     elif (not _iai_version_less_than("2.1.0") and
           _Main.isa(jl_obj, _IAI.GLMNetCVRegressor)):
         L = GLMNetCVRegressor
+    elif (not _iai_version_less_than("3.0.0") and
+          _Main.isa(jl_obj, _IAI.GLMNetCVSurvivalLearner)):
+        L = GLMNetCVSurvivalLearner
+    elif (not _iai_version_less_than("3.0.0") and
+          _Main.isa(jl_obj, _IAI.CategoricalClassificationRewardEstimator)):
+        L = CategoricalClassificationRewardEstimator
+    elif (not _iai_version_less_than("3.0.0") and
+          _Main.isa(jl_obj, _IAI.CategoricalRegressionRewardEstimator)):
+        L = CategoricalRegressionRewardEstimator
+    elif (not _iai_version_less_than("3.0.0") and
+          _Main.isa(jl_obj, _IAI.CategoricalSurvivalRewardEstimator)):
+        L = CategoricalSurvivalRewardEstimator
+    elif (not _iai_version_less_than("3.0.0") and
+          _Main.isa(jl_obj, _IAI.NumericClassificationRewardEstimator)):
+        L = NumericClassificationRewardEstimator
+    elif (not _iai_version_less_than("3.0.0") and
+          _Main.isa(jl_obj, _IAI.NumericRegressionRewardEstimator)):
+        L = NumericRegressionRewardEstimator
+    elif (not _iai_version_less_than("3.0.0") and
+          _Main.isa(jl_obj, _IAI.NumericSurvivalRewardEstimator)):
+        L = NumericSurvivalRewardEstimator
+    elif (not _iai_version_less_than("3.0.0") and
+          _Main.isa(jl_obj, _IAI.EqualPropensityEstimator)):
+        L = EqualPropensityEstimator
 
     return L
 
@@ -162,3 +189,31 @@ from .optimpute import *
 from .optimalfeatureselection import *
 from .rewardestimation import *
 from .heuristics import *
+
+
+# If we are running in a notebook, display any license related warnings
+def _show_license_warnings():  # pragma: no cover
+    def _isnotebook():
+        try:
+            from IPython import get_ipython
+            shell = get_ipython().__class__.__name__
+            if shell == 'ZMQInteractiveShell':
+                return True   # Jupyter notebook or qtconsole
+            elif shell == 'TerminalInteractiveShell':
+                return False  # Terminal running IPython
+            else:
+                return False  # Other type (?)
+        except:
+            return False      # Probably standard Python interpreter
+
+    if _isnotebook():
+        messages = _Main.eval("IAI.IAILicensing.validate_license(1, 1)")
+
+        import logging
+        for _, message in messages:
+            logging.warning(message)
+
+
+# `IAILicensing.validate_license` added in IAI v3
+if not _iai_version_less_than("3.0.0"):
+    _show_license_warnings()
