@@ -12,7 +12,7 @@ class TreeLearner(SupervisedLearner):
         """Return the number of nodes in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_num_nodes <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_num_nodes>`
+        `IAI.get_num_nodes <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_num_nodes>`
 
         Examples
         --------
@@ -24,7 +24,7 @@ class TreeLearner(SupervisedLearner):
         """Return `True` if node `node_index` in the trained learner is a leaf.
 
         Julia Equivalent:
-        `IAI.is_leaf <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.is_leaf>`
+        `IAI.is_leaf <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.is_leaf>`
 
         Examples
         --------
@@ -36,7 +36,7 @@ class TreeLearner(SupervisedLearner):
         """Return the depth of node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_depth <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_depth>`
+        `IAI.get_depth <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_depth>`
 
         Examples
         --------
@@ -49,7 +49,7 @@ class TreeLearner(SupervisedLearner):
         in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_num_samples <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_num_samples>`
+        `IAI.get_num_samples <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_num_samples>`
 
         Examples
         --------
@@ -62,7 +62,7 @@ class TreeLearner(SupervisedLearner):
         trained learner.
 
         Julia Equivalent:
-        `IAI.get_lower_child <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_lower_child>`
+        `IAI.get_lower_child <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_lower_child>`
 
         Examples
         --------
@@ -75,7 +75,7 @@ class TreeLearner(SupervisedLearner):
         trained learner.
 
         Julia Equivalent:
-        `IAI.get_parent <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_parent>`
+        `IAI.get_parent <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_parent>`
 
         Examples
         --------
@@ -88,7 +88,7 @@ class TreeLearner(SupervisedLearner):
         trained learner.
 
         Julia Equivalent:
-        `IAI.get_upper_child <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_upper_child>`
+        `IAI.get_upper_child <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_upper_child>`
 
         Examples
         --------
@@ -101,7 +101,7 @@ class TreeLearner(SupervisedLearner):
         parallel split.
 
         Julia Equivalent:
-        `IAI.is_parallel_split <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.is_parallel_split>`
+        `IAI.is_parallel_split <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.is_parallel_split>`
 
         Examples
         --------
@@ -114,7 +114,7 @@ class TreeLearner(SupervisedLearner):
         hyperplane split.
 
         Julia Equivalent:
-        `IAI.is_hyperplane_split <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.is_hyperplane_split>`
+        `IAI.is_hyperplane_split <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.is_hyperplane_split>`
 
         Examples
         --------
@@ -127,7 +127,7 @@ class TreeLearner(SupervisedLearner):
         categoric split.
 
         Julia Equivalent:
-        `IAI.is_categoric_split <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.is_categoric_split>`
+        `IAI.is_categoric_split <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.is_categoric_split>`
 
         Examples
         --------
@@ -140,7 +140,7 @@ class TreeLearner(SupervisedLearner):
         ordinal split.
 
         Julia Equivalent:
-        `IAI.is_ordinal_split <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.is_ordinal_split>`
+        `IAI.is_ordinal_split <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.is_ordinal_split>`
 
         Examples
         --------
@@ -153,7 +153,7 @@ class TreeLearner(SupervisedLearner):
         categoric/parallel split.
 
         Julia Equivalent:
-        `IAI.is_mixed_parallel_split <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.is_mixed_parallel_split>`
+        `IAI.is_mixed_parallel_split <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.is_mixed_parallel_split>`
 
         Examples
         --------
@@ -166,7 +166,7 @@ class TreeLearner(SupervisedLearner):
         categoric/ordinal split.
 
         Julia Equivalent:
-        `IAI.is_mixed_ordinal_split <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.is_mixed_ordinal_split>`
+        `IAI.is_mixed_ordinal_split <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.is_mixed_ordinal_split>`
 
         Examples
         --------
@@ -179,7 +179,7 @@ class TreeLearner(SupervisedLearner):
         `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.missing_goes_lower <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.missing_goes_lower>`
+        `IAI.missing_goes_lower <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.missing_goes_lower>`
 
         Examples
         --------
@@ -192,7 +192,7 @@ class TreeLearner(SupervisedLearner):
         trained learner.
 
         Julia Equivalent:
-        `IAI.get_split_feature <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_split_feature>`
+        `IAI.get_split_feature <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_split_feature>`
 
         Examples
         --------
@@ -205,7 +205,7 @@ class TreeLearner(SupervisedLearner):
         trained learner.
 
         Julia Equivalent:
-        `IAI.get_split_threshold <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_split_threshold>`
+        `IAI.get_split_threshold <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_split_threshold>`
 
         Examples
         --------
@@ -218,7 +218,7 @@ class TreeLearner(SupervisedLearner):
         `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_split_categories <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_split_categories>`
+        `IAI.get_split_categories <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_split_categories>`
 
         Examples
         --------
@@ -231,7 +231,7 @@ class TreeLearner(SupervisedLearner):
         hyperplane split at  node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_split_weights <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_split_weights>`
+        `IAI.get_split_weights <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_split_weights>`
 
         Examples
         --------
@@ -244,7 +244,7 @@ class TreeLearner(SupervisedLearner):
         features `X` falls.
 
         Julia Equivalent:
-        `IAI.apply <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.apply>`
+        `IAI.apply <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.apply>`
 
         Examples
         --------
@@ -257,7 +257,7 @@ class TreeLearner(SupervisedLearner):
         each node in the learner.
 
         Julia Equivalent:
-        `IAI.apply_nodes <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.apply_nodes>`
+        `IAI.apply_nodes <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.apply_nodes>`
 
         Examples
         --------
@@ -271,7 +271,7 @@ class TreeLearner(SupervisedLearner):
         the features `X` passes through the `j`th node in the learner.
 
         Julia Equivalent:
-        `IAI.decision_path <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.decision_path>`
+        `IAI.decision_path <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.decision_path>`
 
         Examples
         --------
@@ -284,7 +284,7 @@ class TreeLearner(SupervisedLearner):
         features `X`.
 
         Julia Equivalent:
-        `IAI.print_path <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.print_path>`
+        `IAI.print_path <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.print_path>`
 
         Examples
         --------
@@ -300,7 +300,7 @@ class TreeLearner(SupervisedLearner):
         be installed and on the system `PATH`.
 
         Julia Equivalent:
-        `IAI.write_png <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.write_png>`
+        `IAI.write_png <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.write_png>`
 
         Examples
         --------
@@ -316,7 +316,7 @@ class TreeLearner(SupervisedLearner):
         be installed and on the system `PATH`.
 
         Julia Equivalent:
-        `IAI.write_pdf <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.write_pdf>`
+        `IAI.write_pdf <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.write_pdf>`
 
         Compatibility
         -------------
@@ -337,7 +337,7 @@ class TreeLearner(SupervisedLearner):
         be installed and on the system `PATH`.
 
         Julia Equivalent:
-        `IAI.write_svg <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.write_svg>`
+        `IAI.write_svg <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.write_svg>`
 
         Compatibility
         -------------
@@ -355,7 +355,7 @@ class TreeLearner(SupervisedLearner):
         [.dot format](http://www.graphviz.org/content/dot-language/).
 
         Julia Equivalent:
-        `IAI.write_dot <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.write_dot>`
+        `IAI.write_dot <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.write_dot>`
 
         Examples
         --------
@@ -368,7 +368,7 @@ class TreeLearner(SupervisedLearner):
         HTML.
 
         Julia Equivalent:
-        `IAI.write_html <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.write_html>`
+        `IAI.write_html <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.write_html>`
 
         Examples
         --------
@@ -380,7 +380,7 @@ class TreeLearner(SupervisedLearner):
         """Show interactive visualization of learner in default browser.
 
         Julia Equivalent:
-        `IAI.show_in_browser <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.show_in_browser>`
+        `IAI.show_in_browser <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.show_in_browser>`
 
         Examples
         --------
@@ -393,7 +393,7 @@ class TreeLearner(SupervisedLearner):
         HTML.
 
         Julia Equivalent:
-        `IAI.write_questionnaire <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.write_questionnaire>`
+        `IAI.write_questionnaire <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.write_questionnaire>`
 
         Examples
         --------
@@ -406,7 +406,7 @@ class TreeLearner(SupervisedLearner):
         """Show interactive questionnaire based on learner in default browser.
 
         Julia Equivalent:
-        `IAI.show_questionnaire <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.show_questionnaire>`
+        `IAI.show_questionnaire <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.show_questionnaire>`
 
         Examples
         --------
@@ -419,7 +419,7 @@ class TreeLearner(SupervisedLearner):
         using variable importance scores.
 
         Julia Equivalent:
-        `IAI.variable_importance_similarity <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.variable_importance_similarity>`
+        `IAI.variable_importance_similarity <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.variable_importance_similarity>`
 
         Examples
         --------
@@ -449,7 +449,7 @@ class TreeLearner(SupervisedLearner):
         than the tree with the best training objective.
 
         Julia Equivalent:
-        `IAI.get_tree <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_tree>`
+        `IAI.get_tree <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_tree>`
 
         Examples
         --------
@@ -476,7 +476,7 @@ class ClassificationTreeLearner(ClassificationLearner):
         learner.
 
         Julia Equivalent:
-        `IAI.get_classification_label <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_classification_label>`
+        `IAI.get_classification_label <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_classification_label>`
 
         Examples
         --------
@@ -490,7 +490,7 @@ class ClassificationTreeLearner(ClassificationLearner):
         `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_classification_proba <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_classification_proba>`
+        `IAI.get_classification_proba <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_classification_proba>`
 
         Examples
         --------
@@ -504,7 +504,7 @@ class ClassificationTreeLearner(ClassificationLearner):
         node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_regression_constant <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_regression_constant-Tuple%7BTreeLearner%7BIAIBase.ClassificationTask%7D%2CInt64%7D>`
+        `IAI.get_regression_constant <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_regression_constant-Tuple%7BTreeLearner%7BIAIBase.ClassificationTask%7D%2CInt64%7D>`
 
         Examples
         --------
@@ -523,7 +523,7 @@ class ClassificationTreeLearner(ClassificationLearner):
         prediction at node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_regression_weights <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_regression_weights-Tuple%7BTreeLearner%7BIAIBase.ClassificationTask%7D%2CInt64%7D>`
+        `IAI.get_regression_weights <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_regression_weights-Tuple%7BTreeLearner%7BIAIBase.ClassificationTask%7D%2CInt64%7D>`
 
         Examples
         --------
@@ -544,7 +544,7 @@ class ClassificationTreeLearner(ClassificationLearner):
         will be simplified after all changes have been made.
 
         Julia Equivalent:
-        `IAI.set_threshold! <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.set_threshold!>`
+        `IAI.set_threshold! <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.set_threshold!>`
 
         Examples
         --------
@@ -557,7 +557,7 @@ class ClassificationTreeLearner(ClassificationLearner):
         """Show the probability of `display_label` when visualizing learner.
 
         Julia Equivalent:
-        `IAI.set_display_label! <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.set_display_label!>`
+        `IAI.set_display_label! <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.set_display_label!>`
 
         Examples
         --------
@@ -571,7 +571,7 @@ class ClassificationTreeLearner(ClassificationLearner):
         predicted label when visualizing learner.
 
         Julia Equivalent:
-        `IAI.reset_display_label! <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.reset_display_label!>`
+        `IAI.reset_display_label! <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.reset_display_label!>`
 
         Examples
         --------
@@ -591,7 +591,7 @@ class RegressionTreeLearner(RegressionLearner):
         `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_regression_constant <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_regression_constant-Tuple%7BTreeLearner%7BIAIBase.RegressionTask%7D%2CInt64%7D>`
+        `IAI.get_regression_constant <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_regression_constant-Tuple%7BTreeLearner%7BIAIBase.RegressionTask%7D%2CInt64%7D>`
 
         Examples
         --------
@@ -605,7 +605,7 @@ class RegressionTreeLearner(RegressionLearner):
         node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_regression_weights <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_regression_weights-Tuple%7BTreeLearner%7BIAIBase.RegressionTask%7D%2CInt64%7D>`
+        `IAI.get_regression_weights <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_regression_weights-Tuple%7BTreeLearner%7BIAIBase.RegressionTask%7D%2CInt64%7D>`
 
         Examples
         --------
@@ -621,11 +621,11 @@ class SurvivalTreeLearner(SurvivalLearner):
 
     def get_survival_curve(self, node_index, **kwargs):
         """Return the
-        `SurvivalCurve <https://docs.interpretable.ai/v2.2.0/IAI-Python/reference/#SurvivalCurve>`
+        `SurvivalCurve <https://docs.interpretable.ai/v3.0.0/IAI-Python/reference/#SurvivalCurve>`
         at node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_survival_curve <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_survival_curve>`
+        `IAI.get_survival_curve <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_survival_curve>`
 
         Examples
         --------
@@ -640,7 +640,7 @@ class SurvivalTreeLearner(SurvivalLearner):
         the trained learner.
 
         Julia Equivalent:
-        `IAI.get_survival_expected_time <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_survival_expected_time>`
+        `IAI.get_survival_expected_time <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_survival_expected_time>`
 
         Examples
         --------
@@ -659,7 +659,7 @@ class SurvivalTreeLearner(SurvivalLearner):
         trained learner.
 
         Julia Equivalent:
-        `IAI.get_survival_hazard <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_survival_hazard>`
+        `IAI.get_survival_hazard <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_survival_hazard>`
 
         Examples
         --------
@@ -673,6 +673,44 @@ class SurvivalTreeLearner(SurvivalLearner):
         return _IAI.get_survival_hazard_convert(self._jl_obj, node_index,
                                                 **kwargs)
 
+    def get_regression_constant(self, node_index, **kwargs):
+        """Return the constant term in the regression prediction at node
+        `node_index` in the trained learner.
+
+        Julia Equivalent:
+        `IAI.get_regression_constant <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_regression_constant-Tuple%7BTreeLearner%7BIAIBase.SurvivalTask%7D%2CInt64%7D>`
+
+        Examples
+        --------
+        >>> lnr.get_regression_constant(node_index)
+
+        Compatibility
+        -------------
+        Requires IAI version 3.0 or higher.
+        """
+        _requires_iai_version("3.0.0", "get_regression_constant")
+        return _IAI.get_regression_constant_convert(self._jl_obj, node_index,
+                                                    **kwargs)
+
+    def get_regression_weights(self, node_index, **kwargs):
+        """Return the weights for each feature in the regression prediction at
+        node `node_index` in the trained learner.
+
+        Julia Equivalent:
+        `IAI.get_regression_weights <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_regression_weights-Tuple%7BTreeLearner%7BIAIBase.SurvivalTask%7D%2CInt64%7D>`
+
+        Examples
+        --------
+        >>> lnr.get_regression_weights(node_index)
+
+        Compatibility
+        -------------
+        Requires IAI version 3.0 or higher.
+        """
+        _requires_iai_version("3.0.0", "get_regression_weights")
+        return _IAI.get_regression_weights_convert(self._jl_obj, node_index,
+                                                   **kwargs)
+
 
 class PrescriptionTreeLearner(PrescriptionLearner):
     """Abstract type encompassing all tree-based learners with prescription
@@ -684,7 +722,7 @@ class PrescriptionTreeLearner(PrescriptionLearner):
         at node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_prescription_treatment_rank <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_prescription_treatment_rank>`
+        `IAI.get_prescription_treatment_rank <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_prescription_treatment_rank>`
 
         Examples
         --------
@@ -699,7 +737,7 @@ class PrescriptionTreeLearner(PrescriptionLearner):
         node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_regression_constant <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_regression_constant-Tuple%7BTreeLearner%7BIAIBase.PrescriptionTask%7BO%7D%7D%2520where%2520O%2CInt64%2CAny%7D>`
+        `IAI.get_regression_constant <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_regression_constant-Tuple%7BTreeLearner%7BIAIBase.PrescriptionTask%7BO%7D%7D%2520where%2520O%2CInt64%2CAny%7D>`
 
         Examples
         --------
@@ -713,7 +751,7 @@ class PrescriptionTreeLearner(PrescriptionLearner):
         `treatment` at node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_regression_weights <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_regression_weights-Tuple%7BTreeLearner%7BIAIBase.PrescriptionTask%7BO%7D%7D%2520where%2520O%2CInt64%2CAny%7D>`
+        `IAI.get_regression_weights <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_regression_weights-Tuple%7BTreeLearner%7BIAIBase.PrescriptionTask%7BO%7D%7D%2520where%2520O%2CInt64%2CAny%7D>`
 
         Examples
         --------
@@ -732,7 +770,7 @@ class PolicyTreeLearner(PolicyLearner):
         at node `node_index` in the trained learner.
 
         Julia Equivalent:
-        `IAI.get_policy_treatment_rank <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_policy_treatment_rank>`
+        `IAI.get_policy_treatment_rank <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_policy_treatment_rank>`
 
         Examples
         --------
@@ -751,7 +789,7 @@ class PolicyTreeLearner(PolicyLearner):
         trained learner.
 
         Julia Equivalent:
-        `IAI.get_policy_treatment_outcome <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_policy_treatment_outcome>`
+        `IAI.get_policy_treatment_outcome <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_policy_treatment_outcome>`
 
         Examples
         --------
@@ -781,7 +819,7 @@ class AbstractVisualization():
         """Write interactive browser visualization to `filename` as HTML.
 
         Julia Equivalent:
-        `IAI.write_html <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.write_html>`
+        `IAI.write_html <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.write_html>`
 
         Examples
         --------
@@ -793,7 +831,7 @@ class AbstractVisualization():
         """Show interactive visualization in default browser.
 
         Julia Equivalent:
-        `IAI.show_in_browser <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.show_in_browser>`
+        `IAI.show_in_browser <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.show_in_browser>`
 
         Examples
         --------
@@ -806,7 +844,7 @@ class TreePlot(AbstractVisualization):
     """Specify an interactive tree visualization of `lnr`.
 
     Julia Equivalent:
-    `IAI.TreePlot <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.TreePlot>`
+    `IAI.TreePlot <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.TreePlot>`
 
     Examples
     --------
@@ -815,7 +853,7 @@ class TreePlot(AbstractVisualization):
     Parameters
     ----------
     Refer to the
-    `Julia documentation on advanced tree visualization <https://docs.interpretable.ai/v2.2.0/IAITrees/advanced/#Advanced-Visualization-1>`
+    `Julia documentation on advanced tree visualization <https://docs.interpretable.ai/v3.0.0/IAITrees/advanced/#Advanced-Visualization-1>`
     for available parameters.
 
     Compatibility
@@ -832,7 +870,7 @@ class Questionnaire(AbstractVisualization):
     """Specify an interactive questionnaire of `lnr`.
 
     Julia Equivalent:
-    `IAI.Questionnaire <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.Questionnaire>`
+    `IAI.Questionnaire <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.Questionnaire>`
 
     Examples
     --------
@@ -842,7 +880,7 @@ class Questionnaire(AbstractVisualization):
     ----------
 
     Refer to the
-    `Julia documentation on advanced tree visualization <https://docs.interpretable.ai/v2.2.0/IAITrees/advanced/#Advanced-Visualization-1>`
+    `Julia documentation on advanced tree visualization <https://docs.interpretable.ai/v3.0.0/IAITrees/advanced/#Advanced-Visualization-1>`
     for available parameters.
 
     Compatibility
@@ -859,13 +897,13 @@ class MultiQuestionnaire(AbstractVisualization):
     """Specify an interactive questionnaire of multiple tree learners
 
     Julia Equivalent:
-    `IAI.MultiQuestionnaire <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.MultiQuestionnaire>`
+    `IAI.MultiQuestionnaire <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.MultiQuestionnaire>`
 
     Examples
     --------
     Constructs an interactive questionnaire using multiple tree learners from
     specified questions. Refer to the
-    `documentation on advanced tree visualization <https://docs.interpretable.ai/v2.2.0/IAI-Python/julia/#Python-Interactive-Visualizations-1>`
+    `documentation on advanced tree visualization <https://docs.interpretable.ai/v3.0.0/IAI-Python/julia/#Python-Interactive-Visualizations-1>`
     for more information.
 
     >>> iai.MultiQuestionnaire(questions)
@@ -896,13 +934,13 @@ class MultiTreePlot(AbstractVisualization):
     """Specify an interactive tree visualization of multiple tree learners
 
     Julia Equivalent:
-    `IAI.MultiTreePlot <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.MultiTreePlot>`
+    `IAI.MultiTreePlot <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.MultiTreePlot>`
 
     Examples
     --------
     Constructs an interactive tree visualization using multiple tree learners
     from specified questions. Refer to the
-    `documentation on advanced tree visualization <https://docs.interpretable.ai/v2.2.0/IAI-Python/julia/#Python-Interactive-Visualizations-1>`
+    `documentation on advanced tree visualization <https://docs.interpretable.ai/v3.0.0/IAI-Python/julia/#Python-Interactive-Visualizations-1>`
     for more information.
 
     >>> iai.MultiTreePlot(questions)
@@ -936,11 +974,11 @@ class SimilarityComparison(AbstractVisualization):
     `deviations`.
 
     Refer to the
-    `documentation on tree stability <https://docs.interpretable.ai/v2.2.0/IAITrees/stability/#Tree-Stability-1>`
+    `documentation on tree stability <https://docs.interpretable.ai/v3.0.0/IAITrees/stability/#Tree-Stability-1>`
     for more information.
 
     Julia Equivalent:
-    `IAI.SimilarityComparison <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.SimilarityComparison>`
+    `IAI.SimilarityComparison <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.SimilarityComparison>`
 
     Examples
     --------
@@ -965,7 +1003,7 @@ class SimilarityComparison(AbstractVisualization):
         comparison, where a lower value indicates a better solution.
 
         Julia Equivalent:
-        `IAI.get_train_errors <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_train_errors>`
+        `IAI.get_train_errors <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_train_errors>`
 
         Examples
         --------
@@ -1022,11 +1060,11 @@ class StabilityAnalysis(AbstractVisualization):
     """Conduct a stability analysis of the trees in a tree learner.
 
     Refer to the
-    `documentation on tree stability <https://docs.interpretable.ai/v2.2.0/IAITrees/stability/#Tree-Stability-1>`
+    `documentation on tree stability <https://docs.interpretable.ai/v3.0.0/IAITrees/stability/#Tree-Stability-1>`
     for more information.
 
     Julia Equivalent:
-    `IAI.StabilityAnalysis <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.StabilityAnalysis>`
+    `IAI.StabilityAnalysis <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.StabilityAnalysis>`
 
     Examples
     --------
@@ -1057,7 +1095,7 @@ class StabilityAnalysis(AbstractVisualization):
         along with their variable importance scores for each feature.
 
         Julia Equivalent:
-        `IAI.get_stability_results <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_stability_results>`
+        `IAI.get_stability_results <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_stability_results>`
 
         Examples
         --------
@@ -1075,7 +1113,7 @@ class StabilityAnalysis(AbstractVisualization):
         clustering of the best `num_trees` trees.
 
         Julia Equivalent:
-        `IAI.get_cluster_assignments <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_cluster_assignments>`
+        `IAI.get_cluster_assignments <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_cluster_assignments>`
 
         Examples
         --------
@@ -1094,7 +1132,7 @@ class StabilityAnalysis(AbstractVisualization):
         clustering of the best `num_trees` trees.
 
         Julia Equivalent:
-        `IAI.get_cluster_details <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_cluster_details>`
+        `IAI.get_cluster_details <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_cluster_details>`
 
         Examples
         --------
@@ -1113,7 +1151,7 @@ class StabilityAnalysis(AbstractVisualization):
         under the clustering of the best `num_trees` trees.
 
         Julia Equivalent:
-        `IAI.get_cluster_distances <https://docs.interpretable.ai/v2.2.0/IAITrees/reference/#IAI.get_cluster_distances>`
+        `IAI.get_cluster_distances <https://docs.interpretable.ai/v3.0.0/IAITrees/reference/#IAI.get_cluster_distances>`
 
         Examples
         --------
