@@ -1,4 +1,4 @@
-import julia
+import json
 import os
 import pathlib
 import re
@@ -6,10 +6,12 @@ import shutil
 import subprocess
 import sys
 import tarfile
+import time
 import urllib.request
 import zipfile
 
 import appdirs
+import julia
 
 
 APPNAME = 'InterpretableAI'
@@ -118,7 +120,7 @@ def install(runtime=os.environ.get("IAI_JULIA", "julia"), **kwargs):
     Parameters
     ----------
     Refer to the
-    `installation instructions <https://docs.interpretable.ai/v2.2.0/IAI-Python/data/#Python-Installation-1>`
+    `installation instructions <https://docs.interpretable.ai/v3.0.0/IAI-Python/data/#Python-Installation-1>`
     for information on any additional parameters that may be required.
 
     Examples
@@ -139,27 +141,32 @@ def julia_default_install_dir():
 
 
 def julia_latest_version():
-    url = 'https://raw.githubusercontent.com/JuliaBinaryWrappers/Julia_jll.jl/master/Project.toml'
-    toml = urllib.request.urlopen(url).read().decode('utf-8')
-    match = re.search('version = "(.*)\\+(.*?)"', toml)
-    captures = list(match.groups())
-    captures[0] = 'v{0}'.format(captures[0])
-    return captures
+    url = 'https://julialang-s3.julialang.org/bin/versions.json'
+    versions_json = urllib.request.urlopen(url).read().decode('utf-8')
+    versions = json.loads(versions_json)
+    return max(k for (k, v) in versions.items() if v['stable'])
 
 
-def julia_tgz_url(version, build):
-    arch = 'x86_64'
+def julia_tgz_url(version):
+    arch = 'x64'
+    short_version = version[:3]
     if islinux():
-        os_code = 'linux-gnu'
+        os = 'linux'
+        slug = 'linux-x86_64'
+        ext = 'tar.gz'
     elif isapple():
-        os_code = 'apple-darwin14'
+        os = 'mac'
+        slug = 'mac64'
+        ext = 'dmg'
     elif iswindows():
-        os_code = 'w64-mingw32'
+        os = 'winnt'
+        slug = 'win64'
+        ext = 'zip'
     else:  # pragma: no cover
         raise Exception(
             'Unsupported operating system: {0}'.format(appdirs.system))
 
-    url = "https://github.com/JuliaBinaryWrappers/Julia_jll.jl/releases/download/Julia-{0}+{1}/Julia.{0}.{2}-{3}-libgfortran4-cxx11.tar.gz".format(version, build, arch, os_code)
+    url = "https://julialang-s3.julialang.org/bin/{0}/{1}/{2}/julia-{3}-{4}.{5}".format(os, arch, short_version, version, slug, ext)
 
     return url
 
@@ -185,11 +192,15 @@ def julia_load_install_path():
         return None
 
 
-def install_julia(prefix=julia_default_install_dir()):
+def install_julia(version='latest', prefix=julia_default_install_dir()):
     """Download and install Julia automatically.
 
     Parameters
     ----------
+    version : string, optional
+        The version of Julia to install (e.g. `'1.6.3'`).
+        Defaults to `'latest'`, which will install the most recent stable
+        release.
     prefix : string, optional
         The directory where Julia will be installed. Defaults to a location
         determined by
@@ -199,8 +210,9 @@ def install_julia(prefix=julia_default_install_dir()):
     --------
     >>> install_julia(**kwargs)
     """
-    version, build = julia_latest_version()
-    url = julia_tgz_url(version, build)
+    if version == 'latest':
+        version = julia_latest_version()  # pragma: no cover
+    url = julia_tgz_url(version)
 
     print('Downloading {0}'.format(url), file=sys.stderr)
     filename, _ = urllib.request.urlretrieve(url)
@@ -209,8 +221,18 @@ def install_julia(prefix=julia_default_install_dir()):
     if os.path.exists(dest):  # pragma: no cover
         shutil.rmtree(dest)
 
-    with tarfile.open(filename) as f:
-        f.extractall(dest)
+    if islinux():
+        with tarfile.open(filename) as f:
+            f.extractall(dest)
+        subfolder = 'julia-' + version
+    elif iswindows():
+        with zipfile.ZipFile(filename) as f:
+            f.extractall(dest)
+        subfolder = 'julia-' + version
+    elif isapple():
+        subfolder = install_julia_dmg(filename, dest)
+
+    dest = os.path.join(dest, subfolder)
 
     julia_save_install_path(dest)
 
@@ -220,6 +242,62 @@ def install_julia(prefix=julia_default_install_dir()):
     return True
 
 
+# From https://github.com/johnnychen94/jill.py/blob/3b2a29e263ed712f54b0ad2a103083aa2f8045bb/jill/install.py#L221-L238
+def install_julia_dmg(package_path, install_dir):
+    with DmgMounter(package_path) as root:
+        # mounted image contents:
+        #   ['.VolumeIcon.icns', 'Applications', 'Julia-1.3.app']
+        appname = next(filter(lambda x: x.lower().startswith('julia'),
+                              os.listdir(root)))
+        src_path = os.path.join(root, appname)
+        dest_path = os.path.join(install_dir, appname)
+        # preserve lib symlinks, otherwise it might cause troubles
+        # see also: https://github.com/JuliaGPU/CUDA.jl/issues/249
+        shutil.copytree(src_path, dest_path, symlinks=True)
+    return os.path.join(appname, "Contents", "Resources", "julia")
+
+# From https://github.com/johnnychen94/jill.py/blob/3b2a29e263ed712f54b0ad2a103083aa2f8045bb/jill/utils/mount_utils.py#L34-L69
+class DmgMounter():
+    def __init__(self, src_path, mount_root=".", verbose=False, max_try=5):
+        self.src_path = src_path
+        self.mount_root = os.path.abspath(mount_root)
+        mount_name = os.path.splitext(os.path.split(self.src_path)[1])[0]
+        self.mount_point = os.path.join(self.mount_root, mount_name)
+        self.extra_args = ["-mount", "required"]
+        self.max_try = max_try
+        if not verbose:
+            self.extra_args.append("-quiet")
+
+    @staticmethod
+    def umount(mount_point):
+        if os.path.exists(mount_point):
+            rst = subprocess.run(["umount", mount_point])
+            return not rst.returncode
+        return True
+
+    def __enter__(self):  # pragma: no cover
+        assert sys.platform == "darwin"
+        args = ["hdiutil", "attach", self.src_path,
+                "-mountpoint", self.mount_point]
+        args.extend(self.extra_args)
+        DmgMounter.umount(self.mount_point)
+
+        # the mount might fail for unknown reason,
+        # set a max_try here to work it around
+        cur_try = 1
+        while cur_try <= self.max_try:
+            is_success = subprocess.run(args).returncode == 0
+            if is_success:
+                return self.mount_point
+            time.sleep(0.5)
+            cur_try += 1
+
+        raise IOError(f"{self.src_path} is not mounted successfully")
+
+    def __exit__(self, type, value, tb):
+        DmgMounter.umount(self.mount_point)
+
+
 # IAI SYSTEM IMAGE
 
 
@@ -370,3 +448,27 @@ def install_system_image(version='latest', replace_default=False,
     global NEEDS_RESTART
     NEEDS_RESTART = True
     return True
+
+
+def cleanup_installation():
+    """Remove all files created by :meth:`interpretableai.install_julia` and
+    :meth:`interpretableai.install_system_image`.
+
+    Examples
+    --------
+    >>> cleanup_installation()
+    """
+    for f in (
+            julia_path_prefs_file(),
+            sysimage_path_prefs_file(),
+            sysimage_replace_prefs_file(),
+    ):
+        if os.path.exists(f):
+            os.remove(f)
+
+    for path in (
+            julia_default_install_dir(),
+            sysimage_default_install_dir(),
+    ):
+        if os.path.exists(path):
+            shutil.rmtree(path)
