@@ -22,7 +22,7 @@ class OptimalTreeLearner(TreeLearner):
         supplied data.
 
         Julia Equivalent:
-        `IAI.refit_leaves! <https://docs.interpretable.ai/v2.2.0/OptimalTrees/reference/#IAI.refit_leaves!>`
+        `IAI.refit_leaves! <https://docs.interpretable.ai/v3.0.0/OptimalTrees/reference/#IAI.refit_leaves!>`
 
         Examples
         --------
@@ -53,7 +53,7 @@ class OptimalTreeLearner(TreeLearner):
         refit the models in each leaf of the tree using the supplied data.
 
         Julia Equivalent:
-        `IAI.copy_splits_and_refit_leaves! <https://docs.interpretable.ai/v2.2.0/OptimalTrees/reference/#IAI.copy_splits_and_refit_leaves!>`
+        `IAI.copy_splits_and_refit_leaves! <https://docs.interpretable.ai/v3.0.0/OptimalTrees/reference/#IAI.copy_splits_and_refit_leaves!>`
 
         Examples
         --------
@@ -83,12 +83,36 @@ class OptimalTreeLearner(TreeLearner):
             self._jl_obj, orig_lnr, *args, **kwargs)
         return self
 
+    def prune_trees(self, *args, **kwargs):
+        """Use the trained trees in the learner along with the supplied
+        validation data `X` and `y` to determine the best value for the `cp`
+        parameter and then prune the trees according to this value.
+
+        Julia Equivalent:
+        `IAI.prune_trees! <https://docs.interpretable.ai/v3.0.0/OptimalTrees/reference/#IAI.prune_trees!>`
+
+        Examples
+        --------
+        >>> lnr.prune_trees(X, y)
+
+        Parameters
+        ----------
+        Refer to the Julia documentation for available parameters.
+
+        Compatibility
+        -------------
+        Requires IAI version 3.0 or higher.
+        """
+        _requires_iai_version("3.0.0", "prune_trees")
+        _IAI.prune_trees_convert(self._jl_obj, *args, **kwargs)
+        return self
+
 
 class OptimalTreeClassifier(OptimalTreeLearner, ClassificationTreeLearner):
     """Learner for training Optimal Classification Trees.
 
     Julia Equivalent:
-    `IAI.OptimalTreeClassifier <https://docs.interpretable.ai/v2.2.0/OptimalTrees/reference/#IAI.OptimalTreeClassifier>`
+    `IAI.OptimalTreeClassifier <https://docs.interpretable.ai/v3.0.0/OptimalTrees/reference/#IAI.OptimalTreeClassifier>`
 
     Examples
     --------
@@ -107,7 +131,7 @@ class OptimalTreeRegressor(OptimalTreeLearner, RegressionTreeLearner):
     """Learner for training Optimal Regression Trees.
 
     Julia Equivalent:
-    `IAI.OptimalTreeRegressor <https://docs.interpretable.ai/v2.2.0/OptimalTrees/reference/#IAI.OptimalTreeRegressor>`
+    `IAI.OptimalTreeRegressor <https://docs.interpretable.ai/v3.0.0/OptimalTrees/reference/#IAI.OptimalTreeRegressor>`
 
     Examples
     --------
@@ -126,7 +150,7 @@ class OptimalTreeSurvivalLearner(OptimalTreeLearner, SurvivalTreeLearner):
     """Learner for training Optimal Survival Trees.
 
     Julia Equivalent:
-    `IAI.OptimalTreeSurvivalLearner <https://docs.interpretable.ai/v2.2.0/OptimalTrees/reference/#IAI.OptimalTreeSurvivalLearner>`
+    `IAI.OptimalTreeSurvivalLearner <https://docs.interpretable.ai/v3.0.0/OptimalTrees/reference/#IAI.OptimalTreeSurvivalLearner>`
 
     Examples
     --------
@@ -167,7 +191,7 @@ class OptimalTreePrescriptionMinimizer(OptimalTreeLearner,
     should aim to minimize outcomes.
 
     Julia Equivalent:
-    `IAI.OptimalTreePrescriptionMinimizer <https://docs.interpretable.ai/v2.2.0/OptimalTrees/reference/#IAI.OptimalTreePrescriptionMinimizer>`
+    `IAI.OptimalTreePrescriptionMinimizer <https://docs.interpretable.ai/v3.0.0/OptimalTrees/reference/#IAI.OptimalTreePrescriptionMinimizer>`
 
     Examples
     --------
@@ -189,7 +213,7 @@ class OptimalTreePrescriptionMaximizer(OptimalTreeLearner,
     should aim to maximize outcomes.
 
     Julia Equivalent:
-    `IAI.OptimalTreePrescriptionMaximizer <https://docs.interpretable.ai/v2.2.0/OptimalTrees/reference/#IAI.OptimalTreePrescriptionMaximizer>`
+    `IAI.OptimalTreePrescriptionMaximizer <https://docs.interpretable.ai/v3.0.0/OptimalTrees/reference/#IAI.OptimalTreePrescriptionMaximizer>`
 
     Examples
     --------
@@ -210,7 +234,7 @@ class OptimalTreePolicyMinimizer(OptimalTreeLearner, PolicyTreeLearner):
     should aim to minimize outcomes.
 
     Julia Equivalent:
-    `IAI.OptimalTreePolicyMinimizer <https://docs.interpretable.ai/v2.2.0/OptimalTrees/reference/#IAI.OptimalTreePolicyMinimizer>`
+    `IAI.OptimalTreePolicyMinimizer <https://docs.interpretable.ai/v3.0.0/OptimalTrees/reference/#IAI.OptimalTreePolicyMinimizer>`
 
     Examples
     --------
@@ -236,7 +260,7 @@ class OptimalTreePolicyMaximizer(OptimalTreeLearner, PolicyTreeLearner):
     should aim to maximize outcomes.
 
     Julia Equivalent:
-    `IAI.OptimalTreePolicyMaximizer <https://docs.interpretable.ai/v2.2.0/OptimalTrees/reference/#IAI.OptimalTreePolicyMaximizer>`
+    `IAI.OptimalTreePolicyMaximizer <https://docs.interpretable.ai/v3.0.0/OptimalTrees/reference/#IAI.OptimalTreePolicyMaximizer>`
 
     Examples
     --------
