@@ -39,7 +39,7 @@ class CategoricalRewardEstimationLearner(SupervisedLearner):
         estimators during training.
 
         Julia Equivalent:
-        `IAI.fit_predict! <https://docs.interpretable.ai/v2.2.0/RewardEstimation/reference/#IAI.fit_predict!-Tuple%7BLearner%7BIAIBase.CategoricalRewardEstimationTask%7D%7D>`
+        `IAI.fit_predict! <https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.fit_predict!-Tuple%7BLearner%7BIAIBase.CategoricalRewardEstimationTask%7D%7D>`
 
         Examples
         --------
@@ -68,7 +68,7 @@ class CategoricalRewardEstimationLearner(SupervisedLearner):
         observation in the supplied data.
 
         Julia Equivalent:
-        `IAI.predict <https://docs.interpretable.ai/v2.2.0/RewardEstimation/reference/#IAI.predict-Tuple%7BCategoricalRewardEstimator%2CUnion%7BDataFrames.AbstractDataFrame%2C%2520AbstractArray%7Bvar%2522%23s39%2522%2C2%7D%2520where%2520var%2522%23s39%2522%253C%3AReal%7D%7D>`
+        `IAI.predict <https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.predict-Tuple%7BCategoricalRewardEstimator%7BT%7D%2520where%2520T%7D>`
 
         Examples
         --------
@@ -94,6 +94,35 @@ class CategoricalRewardEstimationLearner(SupervisedLearner):
         _requires_iai_version("2.0.0", "predict")
         return _IAI.predict_convert(self._jl_obj, *args, **kwargs)
 
+    def predict_reward(self, *args, **kwargs):
+        """Return counterfactual rewards estimated using the learner parameters
+        for each observation in the supplied data and predictions.
+
+        Julia Equivalent:
+        `IAI.predict_reward <https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.predict_reward-Tuple%7BCategoricalRewardEstimator%7BT%7D%2520where%2520T%7D>`
+
+        Examples
+        --------
+
+        For problems with classification or regression outcomes, predict
+        rewards for each observation in the data given by `treatments` and
+        `outcomes` with predictions given by `predictions`.
+
+        >>> lnr.predict_reward(treatments, outcomes, predictions)
+
+        For problems with survival outcomes, predict rewards for each
+        observation in the data given by `treatments`, `deaths` and `times`,
+        with predictions given by `predictions`.
+
+        >>> lnr.predict_reward(treatments, deaths, times, predictions)
+
+        Compatibility
+        -------------
+        Requires IAI version 3.0 or higher.
+        """
+        _requires_iai_version("3.0.0", "predict_reward")
+        return _IAI.predict_reward_convert(self._jl_obj, *args, **kwargs)
+
     def score(self, *args, **kwargs):
         """Calculate the scores of the internal estimators in the learner on
         the supplied data.
@@ -106,7 +135,7 @@ class CategoricalRewardEstimationLearner(SupervisedLearner):
                         corresponding to each treatment
 
         Julia Equivalent:
-        `IAI.score <https://docs.interpretable.ai/v2.2.0/RewardEstimation/reference/#IAI.score-Tuple%7BCategoricalRewardEstimator%2CUnion%7BDataFrames.AbstractDataFrame%2C%2520AbstractArray%7Bvar%22%23s39%22%2C2%7D%2520where%2520var%22%23s39%22%3C%3AReal%7D%2CArray%7BT%2C1%7D%2520where%2520T%2CArray%7BT%2C1%7D%2520where%2520T%7D>`
+        `IAI.score <https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.score-Tuple%7BCategoricalRewardEstimator%2CUnion%7BDataFrames.AbstractDataFrame%2C%2520AbstractArray%7Bvar%22%23s39%22%2C2%7D%2520where%2520var%22%23s39%22%3C%3AReal%7D%2CArray%7BT%2C1%7D%2520where%2520T%2CArray%7BT%2C1%7D%2520where%2520T%7D>`
 
         Examples
         --------
@@ -136,7 +165,7 @@ class CategoricalClassificationRewardEstimator(CategoricalRewardEstimationLearne
     classification outcomes.
 
     Julia Equivalent:
-    `IAI.CategoricalClassificationRewardEstimator <https://docs.interpretable.ai/v2.2.0/RewardEstimation/reference/#IAI.CategoricalClassificationRewardEstimator>`
+    `IAI.CategoricalClassificationRewardEstimator <https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.CategoricalClassificationRewardEstimator>`
 
     Examples
     --------
@@ -167,7 +196,7 @@ class CategoricalRegressionRewardEstimator(CategoricalRewardEstimationLearner):
     outcomes.
 
     Julia Equivalent:
-    `IAI.CategoricalRegressionRewardEstimator <https://docs.interpretable.ai/v2.2.0/RewardEstimation/reference/#IAI.CategoricalRegressionRewardEstimator>`
+    `IAI.CategoricalRegressionRewardEstimator <https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.CategoricalRegressionRewardEstimator>`
 
     Examples
     --------
@@ -197,7 +226,7 @@ class CategoricalSurvivalRewardEstimator(CategoricalRewardEstimationLearner):
     outcomes.
 
     Julia Equivalent:
-    `IAI.CategoricalSurvivalRewardEstimator <https://docs.interpretable.ai/v2.2.0/RewardEstimation/reference/#IAI.CategoricalSurvivalRewardEstimator>`
+    `IAI.CategoricalSurvivalRewardEstimator <https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.CategoricalSurvivalRewardEstimator>`
 
     Examples
     --------
@@ -229,7 +258,7 @@ class EqualPropensityEstimator(ClassificationLearner):
     be randomly assigned.
 
     Julia Equivalent:
-    `IAI.EqualPropensityEstimator <https://docs.interpretable.ai/v2.2.0/RewardEstimation/reference/#IAI.EqualPropensityEstimator>`
+    `IAI.EqualPropensityEstimator <https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.EqualPropensityEstimator>`
 
     Examples
     --------
@@ -256,7 +285,7 @@ class NumericRewardEstimationLearner(SupervisedLearner):
         estimator.
 
         Julia Equivalent:
-        `IAI.fit_predict! <https://docs.interpretable.ai/v2.2.0/RewardEstimation/reference/#IAI.fit_predict!-Tuple%7BLearner%7BIAIBase.NumericRewardEstimationTask%7D%7D>`
+        `IAI.fit_predict! <https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.fit_predict!-Tuple%7BLearner%7BIAIBase.NumericRewardEstimationTask%7D%7D>`
 
         Examples
         --------
@@ -287,7 +316,7 @@ class NumericRewardEstimationLearner(SupervisedLearner):
         observation in the supplied data.
 
         Julia Equivalent:
-        `IAI.predict <https://docs.interpretable.ai/v2.2.0/RewardEstimation/reference/#IAI.predict-Tuple%7BNumericRewardEstimator%2CUnion%7BDataFrames.AbstractDataFrame%2C%2520AbstractArray%7Bvar%22%23s39%22%2C2%7D%2520where%2520var%22%23s39%22%3C%3AReal%7D%2CArray%7BT%2C1%7D%2520where%2520T%7D>`
+        `IAI.predict <https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.predict-Tuple%7BNumericRewardEstimator%7BT%7D%2520where%2520T%7D>`
 
         Examples
         --------
@@ -319,12 +348,40 @@ class NumericRewardEstimationLearner(SupervisedLearner):
         _requires_iai_version("2.1.0", "predict")
         return _IAI.predict_convert(self._jl_obj, *args, **kwargs)
 
+    def predict_reward(self, *args, **kwargs):
+        """Return counterfactual rewards estimated using the learner parameters
+        for each observation in the supplied data and predictions.
+
+        Julia Equivalent:
+        `IAI.predict_reward <https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.predict_reward-Tuple%7BNumericRewardEstimator%7BT%7D%2520where%2520T%7D>`
+
+        Examples
+        --------
+
+        For problems with classification or regression outcomes, predict
+        rewards for each observation in the data given by `treatments` and
+        `outcomes` with predictions given by `predictions`.
+
+        >>> lnr.predict_reward(X, treatments, outcomes, predictions)
+
+        For problems with survival outcomes, predict rewards for each
+        observation in the data given by `treatments`, `deaths` and `times` with predictions given by `predictions`.
+
+        >>> lnr.predict_reward(X, treatments, deaths, times, predictions)
+
+        Compatibility
+        -------------
+        Requires IAI version 3.0 or higher.
+        """
+        _requires_iai_version("3.0.0", "predict_reward")
+        return _IAI.predict_reward_convert(self._jl_obj, *args, **kwargs)
+
     def score(self, *args, **kwargs):
         """Calculate the scores of the internal estimator in the learner on
         the supplied data.
 
         Julia Equivalent:
-        `IAI.score <https://docs.interpretable.ai/v2.2.0/RewardEstimation/reference/#IAI.score-Tuple%7BNumericRewardEstimator%2CUnion%7BDataFrames.AbstractDataFrame%2C%2520AbstractArray%7Bvar%22%23s39%22%2C2%7D%2520where%2520var%22%23s39%22%3C%3AReal%7D%2CArray%7BT%2C1%7D%2520where%2520T%2CArray%7BT%2C1%7D%2520where%2520T%7D>`
+        `IAI.score <https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.score-Tuple%7BNumericRewardEstimator%2CUnion%7BDataFrames.AbstractDataFrame%2C%2520AbstractArray%7Bvar%22%23s39%22%2C2%7D%2520where%2520var%22%23s39%22%3C%3AReal%7D%2CArray%7BT%2C1%7D%2520where%2520T%2CArray%7BT%2C1%7D%2520where%2520T%7D>`
 
         On IAI versions 2.2 and greater, returns a `dict` with the following
         entries:
@@ -366,7 +423,7 @@ class NumericRewardEstimationLearner(SupervisedLearner):
         for the propensity/outcome estimation problems in the fitted learner.
 
         Julia Equivalent:
-        `IAI.get_estimation_densities <https://docs.interpretable.ai/v2.2.0/RewardEstimation/reference/#IAI.get_estimation_densities>`
+        `IAI.get_estimation_densities <https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.get_estimation_densities>`
 
         Examples
         --------
@@ -386,7 +443,7 @@ class NumericRewardEstimationLearner(SupervisedLearner):
         final tuned values.
 
         Julia Equivalent:
-        `IAI.tune_reward_kernel_bandwidth <https://docs.interpretable.ai/v2.2.0/RewardEstimation/reference/#IAI.tune_reward_kernel_bandwidth>`
+        `IAI.tune_reward_kernel_bandwidth <https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.tune_reward_kernel_bandwidth>`
 
         Examples
         --------
@@ -406,7 +463,7 @@ class NumericRewardEstimationLearner(SupervisedLearner):
         this bandwidth for the original data used to train the learner.
 
         Julia Equivalent:
-        `IAI.set_reward_kernel_bandwidth! <https://docs.interpretable.ai/v2.2.0/RewardEstimation/reference/#IAI.set_reward_kernel_bandwidth!>`
+        `IAI.set_reward_kernel_bandwidth! <https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.set_reward_kernel_bandwidth!>`
 
         Examples
         --------
@@ -426,7 +483,7 @@ class NumericClassificationRewardEstimator(NumericRewardEstimationLearner):
     outcomes.
 
     Julia Equivalent:
-    `IAI.NumericClassificationRewardEstimator <https://docs.interpretable.ai/v2.2.0/RewardEstimation/reference/#IAI.NumericClassificationRewardEstimator>`
+    `IAI.NumericClassificationRewardEstimator <https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.NumericClassificationRewardEstimator>`
 
     Examples
     --------
@@ -456,7 +513,7 @@ class NumericRegressionRewardEstimator(NumericRewardEstimationLearner):
     outcomes.
 
     Julia Equivalent:
-    `IAI.NumericRegressionRewardEstimator <https://docs.interpretable.ai/v2.2.0/RewardEstimation/reference/#IAI.NumericRegressionRewardEstimator>`
+    `IAI.NumericRegressionRewardEstimator <https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.NumericRegressionRewardEstimator>`
 
     Examples
     --------
@@ -486,7 +543,7 @@ class NumericSurvivalRewardEstimator(NumericRewardEstimationLearner):
     outcomes.
 
     Julia Equivalent:
-    `IAI.NumericSurvivalRewardEstimator <https://docs.interpretable.ai/v2.2.0/RewardEstimation/reference/#IAI.NumericSurvivalRewardEstimator>`
+    `IAI.NumericSurvivalRewardEstimator <https://docs.interpretable.ai/v3.0.0/RewardEstimation/reference/#IAI.NumericSurvivalRewardEstimator>`
 
     Examples
     --------
